@@ -13,14 +13,20 @@ import urllib.parse
 import urllib.request
 
 from eliot import start_action
-from rubin_jupyter_utils.helpers import make_logger
+from kubernetes.client import CoreV1Api, RbacAuthorizationV1Api
+from rubin_jupyter_utils.helpers import (
+    make_logger,
+    get_execution_namespace,
+    load_k8s_config,
+)
+from rubin_jupyter_utils.config import RubinConfig
 
 
 class ScanRepo(object):
     """Class to scan repository and create results.
 
-       Based on:
-       https://github.com/shangteus/py-dockerhub/blob/master/dockerhub.py"""
+    Based on:
+    https://github.com/shangteus/py-dockerhub/blob/master/dockerhub.py"""
 
     def __init__(
         self,
@@ -37,8 +43,6 @@ class ScanRepo(object):
         cachefile=None,
         insecure=False,
         debug=False,
-        username=None,
-        password=None,
     ):
         self.data = {}
         self.display_tags = []
@@ -57,8 +61,6 @@ class ScanRepo(object):
         self.path = path
         self.owner = owner
         self.name = name
-        self.username = username
-        self.password = password
         self.experimentals = experimentals
         self.dailies = dailies
         self.weeklies = weeklies
@@ -90,6 +92,9 @@ class ScanRepo(object):
             + "/"
         )
         self.logger.debug("Registry URL: {}".format(self.registry_url))
+        self.config = RubinConfig()
+        load_k8s_config()
+        self.client = CoreV1Api()
 
     def __enter__(self):
         return self
@@ -98,14 +103,12 @@ class ScanRepo(object):
         self.close()
 
     def close(self):
-        """Close the session.
-        """
+        """Close the session."""
         if self._session:
             self._session.close()
 
     def extract_image_info(self):
-        """Build image name list and image description list.
-        """
+        """Build image name list and image description list."""
         with start_action(action_type="extract_image_info"):
 
             cs = []
@@ -350,8 +353,7 @@ class ScanRepo(object):
         return ddate.year, ddate.month, ddate.day  # These are integers
 
     def resolve_tag(self, tag):
-        """Resolve a tag (used for "recommended" or "latest*").
-        """
+        """Resolve a tag (used for "recommended" or "latest*")."""
         with start_action(action_type="resolve_tag"):
             mfest = self._name_to_manifest.get(tag)
             if not mfest:
@@ -400,20 +402,17 @@ class ScanRepo(object):
             return str(o)
 
     def report(self):
-        """Print the tag data.
-        """
+        """Print the tag data."""
         with start_action(action_type="report"):
             print(self._data_to_json())
 
     def get_data(self):
-        """Return the tag data.
-        """
+        """Return the tag data."""
         with start_action(action_type="get_data"):
             return self.data
 
     def get_all_tags(self):
-        """Return all tags in the repository, sorted by semver.
-        """
+        """Return all tags in the repository, sorted by semver."""
         with start_action(action_type="get_all_tags"):
             return self._all_tags
 
@@ -437,8 +436,7 @@ class ScanRepo(object):
         return page
 
     def scan(self):
-        """Perform the repository scan.
-        """
+        """Perform the repository scan."""
         with start_action(action_type="scan"):
             headers = {"Accept": "application/json"}
             url = self.registry_url + "tags/list"
@@ -480,8 +478,7 @@ class ScanRepo(object):
             self.process_resultmap()
 
     def process_resultmap(self):
-        """Take the results from a scan and parse them into usable data.
-        """
+        """Take the results from a scan and parse them into usable data."""
         if not self._results:
             self._synthesize_results_from_resultmap()
         self._map_names_to_manifests()
@@ -759,14 +756,15 @@ class ScanRepo(object):
         with start_action(action_type="_authenticate_to_repo"):
             self.logger.warning("Authentication Required.")
             self.logger.warning("Headers: {}".format(headers))
+            username, password = self._extract_auth_from_pull_secret()
+            if not username and password:  # Didn't extract auth info
+                return {}
             magicheader = headers.get(
                 "WWW-Authenticate", headers.get("Www-Authenticate", None)
             )
             if magicheader.startswith("BASIC"):
                 auth_hdr = base64.b64encode(
-                    "{}:{}".format(self.username, self.password).encode(
-                        "ascii"
-                    )
+                    "{}:{}".format(username, password).encode("ascii")
                 )
                 self.logger.info("Auth header now: {}".format(auth_hdr))
                 return {"Authorization": "Basic " + auth_hdr.decode()}
@@ -789,8 +787,8 @@ class ScanRepo(object):
                 del hd["realm"]
                 # We need to glue in authentication for DELETE, and that alas
                 #  means a userid and password.
-                r_user = self.username
-                r_pw = self.password
+                r_user = username
+                r_pw = password
                 auth = None
                 if r_user and r_pw:
                     auth = (r_user, r_pw)
@@ -811,8 +809,25 @@ class ScanRepo(object):
                 authtok = jresp.get("token")
                 if authtok:
                     self.logger.info("Received an auth token.")
-                    self.logger.warning("{}".format(authtok))
                     return {"Authorization": "Bearer {}".format(authtok)}
                 else:
                     self.logger.error("No auth token: {}".format(jresp))
             return {}
+
+    def _extract_auth_from_pull_secret(self):
+        with start_action(action_type="_extract_auth_from_pull_secret"):
+            host = self.host
+            pull_secret_name = self.config.pull_secret_name
+            if not pull_secret_name:
+                return None, None
+            secret = self.client.read_namespaced_secret(
+                pull_secret_name,
+                get_execution_namespace(),
+            )
+            b64_auths = secret.data[".dockerconfigjson"]
+            json_auths = base64.b64decode(b64_auths).decode("utf-8")
+            auths = json.loads(json_auths)
+            hostauth = auths.get(host)
+            if not hostauth:  # No auth for given host
+                return None, None
+            return hostauth["username"], hostauth["password"]
