@@ -2,10 +2,7 @@
 By analogy with Kubespawner, helper methods for generating K8s API objects
 """
 
-from kubernetes.client.models import (
-    V1Container,
-    V1SecurityContext
-)
+from kubernetes.client.models import V1Container, V1SecurityContext
 
 
 def _create_multus_init_container(image="lsstit/ddsnet4u:latest"):
@@ -14,7 +11,6 @@ def _create_multus_init_container(image="lsstit/ddsnet4u:latest"):
     """
     return V1Container(
         name="multus-init",
-        security_context=V1SecurityContext(
-            privileged=True),
-        image=image
+        security_context=V1SecurityContext(privileged=True),
+        image=image,
     )
