@@ -9,6 +9,8 @@ from rubin_jupyter_utils.helpers import (
     sanitize_dict,
     assemble_gids,
     get_supplemental_gids,
+    call_moneypenny,
+    dossier_from_auth_state,
 )
 from .multispawner import MultiNamespacedKubeSpawner
 from .objects import _create_multus_init_container
@@ -402,10 +404,11 @@ class RubinSpawner(MultiNamespacedKubeSpawner):
             annotations.update(cfg.multus_annotation)
             # If we had a failed spawn, we might already have the container
             #  defined in the pod spec.
-            cnames = [ c.name for c in self.init_containers ]
+            cnames = [c.name for c in self.init_containers]
             if "multus-init" not in cnames:
-                i_ctr=_create_multus_init_container(
-                    cfg.multus_init_container_image)
+                i_ctr = _create_multus_init_container(
+                    cfg.multus_init_container_image
+                )
                 self.init_containers.append(i_ctr)
         if cfg.lab_dds_interface:
             pod_env["LSST_DDS_INTERFACE"] = cfg.lab_dds_interface
@@ -413,6 +416,14 @@ class RubinSpawner(MultiNamespacedKubeSpawner):
             pod_env["LSST_DDS_DOMAIN"] = cfg.lab_dds_domain
         if cfg.lab_dds_partition_prefix:
             pod_env["LSST_DDS_PARTITION_PREFIX"] = cfg.lab_dds_partition_prefix
+        if cfg.butler_s3_endpoint_url:
+            pod_env["S3_ENDPOINT_URL"] = cfg.butler_s3_endpoint_url
+        if cfg.butler_aws_access_key:
+            pod_env["AWS_ACCESS_KEY_ID"] = cfg.butler_aws_access_key
+        if cfg.butler_aws_secret_key:
+            pod_env["AWS_SECRET_ACCESS_KEY"] = cfg.butler_aws_secret_key
+        if cfg.butler_pgpassword:
+            pod_env["PGPASSWORD"] = cfg.butler_pgpassword
         # Generate the pod definition.
         sanitized_env = sanitize_dict(
             pod_env,
@@ -442,6 +453,12 @@ class RubinSpawner(MultiNamespacedKubeSpawner):
                     }
                 }
             )
+        # Check to see if Moneypenny is turned on, and if so, delegate
+        #  provisioning to her.
+        if cfg.turn_on_moneypenny:
+            ast = self.cached_auth_state
+            dossier = dossier_from_auth_state(ast, log=self.log)
+            call_moneypenny(dossier, log=self.log)
         self.set_user_namespace()
         daskconfig = None
         if cfg.allow_dask_spawn:
